
# Audit package

Audit is a comprehensive library designed to eliminate code redundancy by providing reusable audit modules. It simplifies the integration of auditing functionalities into projects, streamlining audit trails, logging, and compliance checks, all in one package. Perfect for maintaining clean and efficient code while meeting audit requirements.



## Tech Stack

**CLI:** This project was generated with Angular CLI version 17.3.1.
**Node:** This project is using v20.9.0




## Build library

Build audit project with npm

**In package.json include next script**

```bash
"postinstall": "[ -d node_modules/audit-library ] && cp -r node_modules/audit-library/src/assets/i18n/audit ./src/main/webapp/i18n",

or

"postinstall": "[ -d node_modules/audit-library ] && cp -r node_modules/audit-library/src/assets/i18n/audit ./src/main/webapp/i18n; [ -d node_modules/notify-library ] && cp -r node_modules/notify-library/src/assets/i18n/notify ./src/main/webapp/i18n"
```

**In webpack.custom.js under i18n**

```bash
{ pattern: './src/main/webapp/i18n/audit/en.json', fileName: './assets/i18n/audit/en.json' },
{ pattern: './src/main/webapp/i18n/audit/ro.json', fileName: './assets/i18n/audit/ro.json' },
{ pattern: './src/main/webapp/i18n/audit/ru.json', fileName: './assets/i18n/audit/ru.json' },
```

```bash
  npm install
  npm run build-library
  npm run pack-library
```


## Instalation library

Install audit project in your project

```bash
 npm install /Users/tudor/Desktop/Work/libraries/audit/dist/audit-library/audit-library-0.0.33999994.tgz
```

**You must install all the dependencies that will occur in terminal as error !**

In your `polyfills.ts`:

```typescript
import '@angular/localize/init';
import 'zone.js';  // Import Zone.js
```

In your `angular.json`:

```typescript
"options": {
  "polyfills": "src/polyfills.ts"
}

"styles": [
    "src/styles.scss",
    "node_modules/bootstrap/dist/css/bootstrap.min.css"
]   ,
```


In your `tsconfig.json`:

```typescript
"include": [
   "src/polyfills.ts"
 ]
```

In your `tsconfig.app.json`:

```typescript
  "compilerOptions": {
    "outDir": "./out-tsc/app",
    "types": [
      "@angular/localize"
    ]
  },
  "include": [
    "src/**/*.d.ts",
    "src/polyfills.ts"
  ]
```

In your `styles.scss`:

```typescript
@import "~@ng-select/ng-select/themes/default.theme.css"; // Import ng-select styles
```


## Usage example
In app.routes.ts file:

```bash
export const routes: Routes = [
  {
    path: 'news',
    component: AuditLibraryComponent,
    data: {
      endpoint: 'http://localhost:8083/api/v1/audits',
      microservice: '',
      defaultSort: 'id,desc'
    },
  }
];
```

- **path** - route where be included audit component

- **component** - importing audit component

- **data** :
  ```json
  {
    "endpoint": "API endpoint that should be called for audit",
    "microservice": "if using microservice, include its name (ex: 'audit')",
    "defaultSort": "default sort of audit values"
  }

