const fs = require('fs');
const path = require('path');

// && node merge-i18n.js

// Define the source directory where your translation files are located
const srcDir = './projects/audit-library/src/assets/i18n'; // The base directory for i18n files
const distDir = './dist/audit-library/src/assets/i18n/audit'; // Output directory for merged files

// Define the languages based on your folder structure
const languages = ['ro', 'ru', 'en'];

languages.forEach((lang) => {
    const langDir = path.resolve(__dirname, `${srcDir}/${lang}`);
    const outputFile = path.resolve(__dirname, `${distDir}/${lang}.json`);

    let mergedData = {};

    // Create the output directory if it doesn't exist
    if (!fs.existsSync(distDir)) {
        fs.mkdirSync(distDir, { recursive: true });
    }

    // Read each JSON file from the language directory and merge
    fs.readdirSync(langDir).forEach(file => {
        if (file.endsWith('.json')) {
            const filePath = path.join(langDir, file);
            const fileContent = JSON.parse(fs.readFileSync(filePath, 'utf-8'));
            mergedData = { ...mergedData, ...fileContent };
        }
    });

    // Write the merged content to the output file
    fs.writeFileSync(outputFile, JSON.stringify(mergedData, null, 2));
    console.log(`Merged ${lang} JSON files into ${outputFile}`);
});