import {Injectable} from "@angular/core";
import {FaIconLibrary} from "@fortawesome/angular-fontawesome";
import {NgbDatepickerConfig} from "@ng-bootstrap/ng-bootstrap";
import {fontAwesomeIcons} from "../shared/constants/font-awesome-icons";
import dayjs from "dayjs/esm";
import {YEAR} from "./dayjs";

@Injectable({
    providedIn: 'root'
})
export class AuditLibraryConfigService {
    private _microservice?: string;
    private _endpointUrl?: string;

    constructor(
        private iconLibrary: FaIconLibrary,
        private dpConfig: NgbDatepickerConfig
    ) {
    }


    get microservice(): string | undefined {
        return this._microservice;
    }

    set microservice(value: string | undefined) {
        this._microservice = value;
    }

    get endpointUrl(): string | undefined {
        return this._endpointUrl;
    }

    set endpointUrl(value: string) {
        this._endpointUrl = value;
    }

    // Method to set the API configuration
    public setConfig(endpoint: string, microservice: string | undefined): void {
        this.endpointUrl = endpoint;
        this.microservice = microservice;
    }

    public configureLibrary() {
        // Set FontAwesome icons
        this.iconLibrary.addIcons(...fontAwesomeIcons);

        // Configure Datepicker
        this.dpConfig.minDate = {
            year: dayjs().subtract(100, YEAR).year(),
            month: 1,
            day: 1
        };
    }
}