import dayjs from 'dayjs/esm';
import { FilterAudit } from './audit.model';
import {Pageable} from "../shared/query/query.builder";
import {DATE_TIME_FORMAT} from "../shared/constants/input.constants";

export class AuditQueryBuilder {
  jsonObject: any = {};

  public build(filter: FilterAudit, pageable?: Pageable): any {
    if (pageable?.page) {
      this.jsonObject['page'] = pageable.page;
    }
    if (pageable?.size) {
      this.jsonObject['size'] = pageable.size;
    }
    if (pageable?.sort) {
      this.jsonObject['sort'] = pageable.sort;
    }

    if (filter.eventDateStart) {
      this.jsonObject['createdDate.greaterThanOrEqual'] = dayjs(filter.eventDateStart, DATE_TIME_FORMAT).startOf('day').locale('md');
    }
    if (filter.eventDateEnd) {
      this.jsonObject['createdDate.lessThanOrEqual'] = dayjs(filter.eventDateEnd, DATE_TIME_FORMAT)
        .add(1, 'day')
        .startOf('day')
        .subtract(1, 'millisecond')
        .locale('md');
    }

    if (filter.id) {
      this.jsonObject['id.equals'] = filter.id;
    }

    if (filter.auditEventType) {
      this.jsonObject['auditEventType.equals'] = filter.auditEventType.code;
    }

    if (filter.objectId) {
      this.jsonObject['objectId.contains'] = filter.objectId.trim();
    }

    if (filter.objectName) {
      this.jsonObject['objectName.contains'] = filter.objectName.trim();
    }

    if (filter.ipAddress) {
      this.jsonObject['ipAddress.contains'] = filter.ipAddress.trim();
    }

    if (filter.user) {
      this.jsonObject['principal.contains'] = filter.user.idnp;
    }

    if (filter.objectType) {
      this.jsonObject['objectType.equals'] = filter.objectType;
    }

    if (filter.serviceName) {
      this.jsonObject['service.equals'] = filter.serviceName;
    }

    return this.jsonObject;
  }
}
