import dayjs from 'dayjs/esm';
import {User} from '../shared/model/user.model';
import {AuditServiceName} from './audit-service-name.enum';

export interface IEventType {
    id?: string;
    code?: string;
    name?: string;
    nameRus?: string;
    nameEng?: string;
    status?: string;
    objectType?: string;
}

export enum ObjectType {
    User = 'User',
    Account = 'Account',
}

export class AuditEventTypes {
    constructor(
        public id: number,
        public code: string,
        public name: string,
        public nameRus: string,
        public nameEng: string,
        public nickName?: string,
        public status?: string,
        public objectType?: ObjectType,
    ) {
    }
}

export class FilterAudit {
    constructor(
        public id?: string,
        public idno?: string,
        public ipAddress?: string,
        public objectId?: string,
        public objectName?: string,
        public auditEventType?: IEventType,
        public eventDateStart?: dayjs.Dayjs,
        public eventDateEnd?: dayjs.Dayjs,
        public user?: User,
        public serviceName?: keyof typeof AuditServiceName | null,
        public objectType?: ObjectType,
    ) {
    }
}

export class Audit {
    constructor(
        public id: string,
        public description: string,
        public ipAddress: string,
        public principal: string,
        public principalDetails: string,
        public objectName: string,
        public objectId: string,
        public service: string,
        public data: string,
        public previous: string,
        public current: string,
        public objectType: ObjectType,
        public createdDate: dayjs.Dayjs,
        public eventType: IEventType,
        public eventTypeData: { key: string; value: string },
        public objectKeysData?: { key: string; value: string }[],
        public objectKeysPrevData?: { key: string; value: string }[],
        public objectKeysCurrentData?: { key: string; value: string }[],
    ) {
    }
}
