import {Component, EventEmitter, Input, OnChanges, OnInit, Output, SimpleChanges} from '@angular/core';
import {AuditEventTypes, IEventType, ObjectType } from '../../model/audit.model';
import { ITEMS_PER_PAGE } from '../constants/pagination.constants';
import { NgSelectScrollService } from '../ng-select-scroll/ng-select-scroll-service';
import {AuditLibraryService} from "../../audit-library.service";
import {ASC} from "../constants/navigation.constants";
import {NgSelectModule} from "@ng-select/ng-select";
import {LanguageModule} from "../language/language.module";
import {FormsModule} from "@angular/forms";
import {NgbTooltip} from "@ng-bootstrap/ng-bootstrap";

@Component({
  standalone: true,
  imports: [
    NgSelectModule,
    LanguageModule,
    FormsModule,
    NgbTooltip
  ],
  selector: 'jhi-audit-audit-event-type',
  templateUrl: './event-type.component.html',
})
export class AuditEventTypeComponent implements OnInit, OnChanges {
  @Input() selected: IEventType | null | undefined;
  @Input() reseted = false;
  @Input() resetedObjectType = false;
  @Output() selectedEventType: EventEmitter<any> = new EventEmitter<any>();

  @Input() objectType: ObjectType | undefined = undefined;

  listAudit: AuditEventTypes[] = [];

  loading = false;
  currentPage = 0;
  searchQuery = '';
  selectedItem: IEventType | null = null;
  itemPerPage = ITEMS_PER_PAGE;

  ngSelect = new NgSelectScrollService();

  constructor(private auditService: AuditLibraryService) {}

  ngOnInit(): void {
    if (this.selected) {
      this.selectedItem = this.selected;
    }
    this.search();
  }

  query(): void {
    if (this.objectType) {
      this.listAudit = [];
      this.auditService.getDataLogsByObjectType(this.objectType).subscribe({
        next: res => {
          this.loading = false;
          if (res.body) {
            this.listAudit = [...this.listAudit, ...res.body];
          }
        },
      });
    } else {
      this.search();
    }
  }

  search(): void {
    this.auditService
      .searchDataLogs({
        searchTerm: this.searchQuery,
        page: this.currentPage,
        size: this.itemPerPage,
        sort: ['name', ASC],
      })
      .subscribe({
        next: res => {
          this.loading = false;
          if (res.body) {
            this.listAudit = [...this.listAudit, ...res.body];
          }
        },
      });
  }

  onClear(): void {
    this.currentPage = 0;
    this.listAudit = [];
    this.searchQuery = '';
    this.loading = true;
    this.ngSelect = new NgSelectScrollService();
    this.query();
  }

  onQueryChange($event: any): void {
    const value = $event.target.value;
    this.searchQuery = value.trim();
    this.currentPage = 0;
    this.listAudit = [];

    if (value.trim().length >= 1) {
      this.search();
    } else {
      this.onClear();
    }
  }

  onScrollToEnd(e: any): void {
    if (e.end > this.listAudit.length - 1) {
      if (!this.objectType || this.searchQuery) {
        this.ngSelect.Scroll(e, 'listAudit', () => {
          this.currentPage++;
          this.search();
        });
      }
    }
  }

  onChange(): void {
    this.selectedEventType.emit({ eventType: this.selectedItem });
  }

  reset(): void {
    this.currentPage = 0;
    this.searchQuery = '';
    this.selectedItem = null;
    this.ngSelect = new NgSelectScrollService();
  }

  customSearch(item: any): any {
    return item;
  }

  ngOnChanges(changes: SimpleChanges): void {
    // eslint-disable-next-line @typescript-eslint/no-unnecessary-condition
    if (!changes['reseted']?.firstChange && changes['reseted']?.previousValue !== changes['reseted']?.currentValue) {
      this.selectedItem = null;
    }

    // eslint-disable-next-line @typescript-eslint/no-unnecessary-condition
    if (
      !changes['resetedObjectType']?.firstChange &&
      changes['resetedObjectType']?.previousValue !== changes['resetedObjectType']?.currentValue
    ) {
      this.reset();
    }

    // eslint-disable-next-line @typescript-eslint/no-unnecessary-condition
    if (!changes['objectType']?.firstChange && changes['objectType']?.previousValue !== changes['objectType']?.currentValue) {
      this.query();
    }
  }
}
