import { Component, EventEmitter, Input, OnChanges, OnInit, Output, SimpleChanges } from '@angular/core';
import { FilterAudit, ObjectType } from '../../model/audit.model';
import { ITEMS_PER_PAGE } from '../constants/pagination.constants';
import {NgSelectScrollService} from "../ng-select-scroll/ng-select-scroll-service";
import {AuditLibraryService} from "../../audit-library.service";
import {NgSelectModule} from "@ng-select/ng-select";
import {LanguageModule} from "../language/language.module";
import {FormsModule} from "@angular/forms";

@Component({
  standalone: true,
  imports: [
    NgSelectModule,
    LanguageModule,
    FormsModule
  ],
  selector: 'jhi-audit-audit-object-type',
  templateUrl: './object-type.component.html',
})
export class AuditObjectTypeComponent implements OnInit, OnChanges {
  @Input() selected: ObjectType | null | undefined;
  @Input() reseted = false;
  @Output() selectedObjectType: EventEmitter<any> = new EventEmitter<any>();

  @Input() filter: FilterAudit = new FilterAudit();

  objectTypes: ObjectType[] = [];

  loading = false;
  currentPage = 0;
  searchQuery = '';
  selectedItem: ObjectType | null = null;
  itemPerPage = ITEMS_PER_PAGE;

  ngSelect = new NgSelectScrollService();

  constructor(private auditService: AuditLibraryService) {}

  ngOnInit(): void {
    if (this.selected) {
      this.selectedItem = this.selected;
    }

    this.listObjectTypes();
  }

  listObjectTypes(): void {
    this.auditService.queryObjectType().subscribe(res => {
      if (res.body) {
        this.objectTypes = res.body.auditObjectTypes;
      }
    });
  }

  onChange(): void {
    this.selectedObjectType.emit({ objectType: this.selectedItem });
  }

  customSearch(term: string, item: any): any {
    term = term.toLocaleLowerCase().trim();
    return (
      item.name!.toLocaleLowerCase().includes(term) ||
      item.nameEng!.toLocaleLowerCase().includes(term) ||
      item.nameRus!.toLocaleLowerCase().includes(term)
    );
  }

  ngOnChanges(changes: SimpleChanges): void {
    // eslint-disable-next-line @typescript-eslint/no-unnecessary-condition
    if (!changes['reseted']?.firstChange && changes['reseted']?.previousValue !== changes['reseted']?.currentValue) {
      this.selectedItem = null;
    }
  }
}
