import {Component, EventEmitter, Input, OnChanges, OnInit, Output, SimpleChanges} from '@angular/core';
import {LanguageModule} from '../language/language.module';
import {IUser} from '../model/user.model';
import {ITEMS_PER_PAGE} from '../constants/pagination.constants';
import {NgSelectScrollService} from '../ng-select-scroll/ng-select-scroll-service';
import {AuditLibraryService} from "../../audit-library.service";
import {NgSelectModule} from "@ng-select/ng-select";
import {FormsModule} from "@angular/forms";

@Component({
  standalone: true,
  imports: [LanguageModule, NgSelectModule, FormsModule],
  selector: 'jhi-audit-users',
  templateUrl: './users.component.html',
})
export class AuditUsersComponent implements OnInit, OnChanges {
  @Input() showIdnpOnly = false;
  @Input() selected: IUser | null | undefined;
  @Input() reseted = false;
  @Output() selectedUser: EventEmitter<any> = new EventEmitter<any>();

  users: IUser[] = [];
  loading = false;
  currentPage = 0;
  searchQuery = '';
  selectedItem: IUser | null = null;
  itemPerPage = ITEMS_PER_PAGE;

  ngSelect = new NgSelectScrollService();

  constructor(private auditService: AuditLibraryService) {}

  ngOnInit(): void {
    if (this.selected) {
      this.selectedItem = this.selected;
    }
    this.search();
  }

  search(): void {
    this.loading = true;
    this.auditService
      .queryUsers({
        searchTerm: this.searchQuery,
        page: this.currentPage,
        size: this.itemPerPage
      })
      .subscribe({
        next: res => {
          this.loading = false;
          if (res.body) {
            this.users = [...this.users, ...res.body];
          }
        },
      });
  }

  onClear(): void {
    this.currentPage = 0;
    this.users = [];
    this.searchQuery = '';
    this.loading = true;
    this.ngSelect = new NgSelectScrollService();
    this.search();
  }

  onQueryChange($event: any): void {
    const value = $event.target.value;
    this.searchQuery = value.trim();
    this.currentPage = 0;
    this.users = [];

    if (value.trim().length >= 1) {
      this.search();
    } else {
      this.onClear();
    }
  }

  onScrollToEnd(e: any): void {
    if (e.end > this.users.length - 1) {
      this.ngSelect.Scroll(e, 'users', () => {
        this.currentPage++;
        this.search();
      });
    }
  }

  onChange(): void {
    this.selectedUser.emit({ user: this.selectedItem });
  }

  reset(): void {
    this.currentPage = 0;
    this.searchQuery = '';
    this.selectedItem = null;
    this.ngSelect = new NgSelectScrollService();
  }

  customSearch(term: string, item: any): any {
    return item;
  }

  ngOnChanges(changes: SimpleChanges): void {
    // eslint-disable-next-line @typescript-eslint/no-unnecessary-condition
    if (!changes['reseted']?.firstChange && changes['reseted']?.previousValue !== changes['reseted']?.currentValue) {
      this.selectedItem = null;
    }
  }
}
