/* eslint-disable curly, no-console */

import { Injectable } from '@angular/core';
import { NgbDateAdapter, NgbDateParserFormatter, NgbDateStruct } from '@ng-bootstrap/ng-bootstrap';
import dayjs from 'dayjs/esm';
import { MEDIUM_DATE_FORMAT } from '../constants/input.constants';

@Injectable()
export class DateInputFormatter extends NgbDateParserFormatter {
  public parse(value: string): NgbDateStruct | null {
    if (!value || value.length <= 7) return null;

    const date = dayjs(value);

    return {
      year: date.year(),
      month: date.month(),
      day: date.day(),
    };
  }

  public format(date: NgbDateStruct): string {
    // eslint-disable-next-line @typescript-eslint/no-unnecessary-condition
    if (!date) return '';

    const input = date.year.toString() + '-' + date.month.toString().padStart(2, '0') + '-' + date.day.toString().padStart(2, '0');

    return dayjs(input).format(MEDIUM_DATE_FORMAT);
  }
}

/**
 * This Service handles how the date is represented in scripts i.e. ngModel.
 */
@Injectable()
export class CustomAdapter extends NgbDateAdapter<string> {
  readonly DELIMITER = '-';

  fromModel(value: string | null): NgbDateStruct | null {
    if (value) {
      const date = value.split(this.DELIMITER);
      return {
        day: parseInt(date[0], 10),
        month: parseInt(date[1], 10),
        year: parseInt(date[2], 10),
      };
    }
    return null;
  }

  toModel(date: NgbDateStruct | null): string | null {
    return date
      ? (date.day.toString().length === 1 ? '0'.concat(date.day.toString()) : date.day.toString())
          .concat(this.DELIMITER)
          .concat(date.month.toString().length === 1 ? '0'.concat(date.month.toString()) : date.month.toString())
          .concat(this.DELIMITER)
          .concat(date.year.toString())
      : null;
  }
}

/**
 * This Service handles how the date is rendered and parsed from keyboard i.e. in the bound input field.
 */
@Injectable()
export class CustomDateParserFormatter extends NgbDateParserFormatter {
  readonly DELIMITER = '.';

  parse(value: string): NgbDateStruct | null {
    if (value) {
      const date = value.split(this.DELIMITER);
      return {
        day: parseInt(date[0], 10),
        month: parseInt(date[1], 10),
        year: parseInt(date[2], 10),
      };
    }
    return null;
  }

  format(date: NgbDateStruct | null): string {
    return date
      ? (date.day.toString().length === 1 ? '0'.concat(date.day.toString()) : date.day.toString())
          .concat(this.DELIMITER)
          .concat(date.month.toString().length === 1 ? '0'.concat(date.month.toString()) : date.month.toString())
          .concat(this.DELIMITER)
          .concat(date.year.toString())
      : '';
  }
}
