import {Component, EventEmitter, Input, OnChanges, OnInit, Output, SimpleChanges} from '@angular/core';
import {ITEMS_PER_PAGE, ITEMS_PER_PAGE10, ITEMS_PER_PAGE100, ITEMS_PER_PAGE50} from "../constants/pagination.constants";
import {NgSelectModule} from "@ng-select/ng-select";
import {FormsModule} from "@angular/forms";
import TranslateDirective from "../language/translate.directive";
import {LanguageModule} from "../language/language.module";

@Component({
  standalone: true,
  imports: [
    NgSelectModule,
    FormsModule,
    TranslateDirective,
    LanguageModule
  ],
  selector: 'jhi-items-per-page',
  templateUrl: './items-per-page.component.html',
})
export class ItemsPerPageComponent implements OnInit, OnChanges {
  @Input() selected: number | undefined | null;
  @Input() reseted = false;
  @Output() selectedItemOutput = new EventEmitter<{ item: number | null }>();

  items = Object.entries([ITEMS_PER_PAGE10, ITEMS_PER_PAGE, ITEMS_PER_PAGE50, ITEMS_PER_PAGE100]).map(entry => {
    const [key, value] = entry;
    return {
      key,
      value,
    };
  });
  selectedItem: number | null = null;

  ngOnInit(): void {
    if (this.selected) {
      this.selectedItem = this.selected;
    } else {
      this.selectedItem = this.items[0].value;
    }
  }

  onChange(): void {
    this.selectedItemOutput.emit({ item: this.selectedItem });
  }

  reset(): void {
    this.selectedItem = null;
  }

  ngOnChanges(changes: SimpleChanges): void {
    // eslint-disable-next-line @typescript-eslint/no-unnecessary-condition
    if (!changes['reseted']?.firstChange && changes['reseted']?.previousValue !== changes['reseted']?.currentValue) {
      this.selectedItem = null;
    }
  }
}
