import { Directive, ElementRef, Input, OnChanges, OnDestroy, OnInit, Renderer2 } from '@angular/core';
import { LangChangeEvent, TranslateService } from '@ngx-translate/core';
import { Subscription } from 'rxjs';
import {StateStorageService} from "../state-storage.service";

@Directive({
  standalone: true,
  selector: '[jhiTranslate2]',
})
export default class Translate2Directive implements OnChanges, OnInit, OnDestroy {
  @Input()
  jhiTranslate2!: any;
  locale?: string;
  onLangChange: Subscription | undefined;

  constructor(
    private el: ElementRef,
    private renderer: Renderer2,
    private translateService: TranslateService,
    private sessionStorageService: StateStorageService,
  ) {
    this.locale = this.sessionStorageService.getLocale() ?? 'ro';
  }

  ngOnInit(): void {
    this.onLangChange = this.translateService.onLangChange.subscribe((langChangeEvent: LangChangeEvent) => {
      this.locale = langChangeEvent.lang;
      this.getTranslation();
    });
  }

  ngOnChanges(): void {
    this.getTranslation();
  }

  ngOnDestroy(): void {
    if (this.onLangChange) {
      this.onLangChange.unsubscribe();
      this.onLangChange = undefined;
    }
  }

  private getTranslation(): void {
    this.el.nativeElement.innerHTML = this.jhiTranslate2[this.locale!];
  }
}
