import { Directive, ElementRef, Input, OnChanges, OnDestroy, OnInit, Renderer2 } from '@angular/core';
import { LangChangeEvent, TranslateService } from '@ngx-translate/core';
import { Subscription } from 'rxjs';
import { StateStorageService } from '../state-storage.service';
import { LANGUAGES } from '../constants/language.constants';

@Directive({
  standalone: true,
  selector: '[jhiTranslate3]',
})
export default class Translate3Directive implements OnChanges, OnInit, OnDestroy {
  @Input()
  jhiTranslate3!: any;
  locale?: string;
  onLangChange: Subscription | undefined;

  constructor(
    private el: ElementRef,
    private renderer: Renderer2,
    private translateService: TranslateService,
    private sessionStorageService: StateStorageService,
  ) {
    this.locale = this.sessionStorageService.getLocale() ?? 'ro';
  }

  ngOnInit(): void {
    this.onLangChange = this.translateService.onLangChange.subscribe((langChangeEvent: LangChangeEvent) => {
      this.locale = langChangeEvent.lang;
      this.getTranslation();
    });
  }

  ngOnChanges(): void {
    this.getTranslation();
  }

  ngOnDestroy(): void {
    if (this.onLangChange) {
      this.onLangChange.unsubscribe();
      this.onLangChange = undefined;
    }
  }

  private getTranslation(): void {
    switch (this.locale!) {
      case LANGUAGES[0]:
        this.el.nativeElement.innerHTML = this.jhiTranslate3.nameRo || this.jhiTranslate3.name;
        break;
      case LANGUAGES[1]:
        this.el.nativeElement.innerHTML = this.jhiTranslate3.nameeng || this.jhiTranslate3.nameEng || this.jhiTranslate3.nameEn;
        break;
      case LANGUAGES[2]:
        this.el.nativeElement.innerHTML = this.jhiTranslate3.namerus || this.jhiTranslate3.nameRus || this.jhiTranslate3.nameRu;
        break;
      default:
        this.el.nativeElement.innerHTML = this.jhiTranslate3.nameRo || this.jhiTranslate3.name;
    }
  }
}
