import { Injectable, OnDestroy, Pipe, PipeTransform } from '@angular/core';
import { LangChangeEvent, TranslateService } from '@ngx-translate/core';
import { Subscription } from 'rxjs';
import { StateStorageService } from '../state-storage.service';
import {LANGUAGES} from "../constants/language.constants";

@Injectable()
@Pipe({
  standalone: true,
  name: 'translate3',
  pure: false,
})
export default class Translate3Pipe implements PipeTransform, OnDestroy {
  value: any;
  locale?: string;
  onLangChange: Subscription | undefined;

  constructor(
    private translate: TranslateService,
    private sessionStorageService: StateStorageService,
  ) {
    this.locale = this.sessionStorageService.getLocale() ?? 'ro';
  }

  updateValue(translations?: any): void {
    if (!this.value) {
      switch (this.locale!) {
        case LANGUAGES[0]:
          this.value = translations?.name || translations?.nameRo;
          break;
        case LANGUAGES[1]:
          this.value = translations?.nameeng || translations?.nameEng || translations?.nameEn;
          break;
        case LANGUAGES[2]:
          this.value = translations?.namerus || translations?.nameRus || translations?.nameRu;
          break;
        default:
          this.value = translations.name || translations.nameRo;
      }
    }
  }

  transform(obj: any): any {
    this.updateValue(obj);
    if (!this.onLangChange) {
      this.onLangChange = this.translate.onLangChange.subscribe((event: LangChangeEvent) => {
        this.locale = event.lang;
        this.value = undefined;
        this.updateValue(event.translations);
      });
    }
    return this.value;
  }

  ngOnDestroy(): void {
    if (this.onLangChange) {
      this.onLangChange.unsubscribe();
      this.onLangChange = undefined;
    }
  }
}
