import {NgModule} from '@angular/core';
import {HttpClient, provideHttpClient, withInterceptorsFromDi} from '@angular/common/http';
import {MissingTranslationHandler, TranslateLoader, TranslateModule, TranslateService} from '@ngx-translate/core';
import {StateStorageService} from "../state-storage.service";
import {missingTranslationHandler, translatePartialLoader} from '../../config/translation.config';
import {LANGUAGES} from "../constants/language.constants";

@NgModule({
    imports: [
        TranslateModule.forRoot({
            loader: {
                provide: TranslateLoader,
                useFactory: translatePartialLoader,
                deps: [HttpClient],
            },
            missingTranslationHandler: {
                provide: MissingTranslationHandler,
                useFactory: missingTranslationHandler,
            },
        }),
    ],
    providers: [provideHttpClient(withInterceptorsFromDi())],
})
export class TranslationModule {
    constructor(
        private translateService: TranslateService,
        private stateStorageService: StateStorageService,
    ) {
        this.translateService.setDefaultLang(LANGUAGES[0]);
        // if user have changed language and navigates away from the application and back to the application then use previously choosed language
        const langKey = this.stateStorageService.getLocale() ?? LANGUAGES[0];
        this.translateService.use(langKey);
    }
}
